==> 0.1.2.tar.gz: lib/mfsdk.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';

import 'package:mfsdk/model/MFError.dart';
import 'package:mfsdk/model/directpayment/MFCardInfo.dart';
import 'package:mfsdk/model/directpayment/SDKDirectPaymentResponse.dart';
import 'package:mfsdk/model/executepayment/MFExecutePaymentRequest.dart';
import 'package:mfsdk/model/executepayment/SDKExecutePaymentResponse.dart';
import 'package:mfsdk/model/MyBaseResponse.dart';
import 'package:mfsdk/model/initpayment/SDKInitiatePaymentResponse.dart';
import 'package:mfsdk/model/paymentstatus/MFPaymentStatusRequest.dart';
import 'package:mfsdk/model/paymentstatus/SDKPaymentStatusResponse.dart';
import 'package:mfsdk/utils/MFResult.dart';
import 'package:mfsdk/utils/APPCONST.dart';

import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:http/http.dart' as http;
import 'dart:convert';
import 'dart:io';

// Export all MyFatoorah SDK packages
export 'package:mfsdk/model/directpayment/MFCardInfo.dart';
export 'package:mfsdk/model/directpayment/SDKDirectPaymentResponse.dart';
export 'package:mfsdk/model/executepayment/MFExecutePaymentRequest.dart';
export 'package:mfsdk/model/executepayment/SDKExecutePaymentResponse.dart';
export 'package:mfsdk/model/initpayment/MFInitiatePaymentRequest.dart';
export 'package:mfsdk/model/initpayment/SDKInitiatePaymentResponse.dart';
export 'package:mfsdk/model/MFError.dart';
export 'package:mfsdk/model/MyBaseResponse.dart';
export 'package:mfsdk/model/paymentstatus/MFPaymentStatusRequest.dart';
export 'package:mfsdk/model/paymentstatus/SDKPaymentStatusResponse.dart';
export 'package:mfsdk/utils/APPCONST.dart';
export 'package:mfsdk/utils/MFResult.dart';

var MFSDK = new MyFatoorahSDK();

class MyFatoorahSDK implements CallBackPaymentStatus {

  static const MethodChannel _channel =
  const MethodChannel('mfsdk');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Function func;
  BuildContext myContext;

  // Initiate Payment
  void initiatePayment(String apiLang, Map request, Function func) async{

    http.post(
        APPCONST.INITIATE_PAYMENT,
        headers: {
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: request).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKInitiatePaymentResponse
          .fromJson(json.decode(response.body)).data;
      print(result.toJson());
      func(MFResult.success(result));
    });

//    func((await MFSDKController().initiatePaymentAPI(apiLang, url, token, data)).data);
  }

  // Execute  Payment
  void executePayment(BuildContext context,
      MFExecutePaymentRequest request, String apiLang, Function func) async{

    if(request.callBackUrl == null || request.callBackUrl.isEmpty)
      request.callBackUrl = APPCONST.CALL_BACK_URL;

    if(request.errorUrl == null || request.errorUrl.isEmpty)
      request.errorUrl = APPCONST.ERROR_URL;

    http.post(
        APPCONST.EXECUTE_PAYMENT,
        headers: {
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: request.toJson()).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        print("statusCode: " + statusCode.toString());
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKExecutePaymentResponse
          .fromJson(json.decode(response.body)).data;

      if (!result.isDirectPayment) {
        this.func = func;
        this.myContext = context;
        showWebView(result.paymentURL);
      }
      else
        func(MFResult.fail(new MFError(APPCONST.CONFIG_ERROR, APPCONST.incorrectPaymentMethod)));
    });
  }

  // Execute Direct Payment
  void executeDirectPayment(BuildContext context,
      MFExecutePaymentRequest request, MFCardInfo mfCardInfo, String apiLang,
      Function func) async{

    if(request.callBackUrl == null || request.callBackUrl.isEmpty)
      request.callBackUrl = APPCONST.CALL_BACK_URL;

    if(request.errorUrl == null || request.errorUrl.isEmpty)
      request.errorUrl = APPCONST.ERROR_URL;

    http.post(
        APPCONST.EXECUTE_PAYMENT,
        headers: {
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: request.toJson()).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        print("statusCode: " + statusCode.toString());
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKExecutePaymentResponse
          .fromJson(json.decode(response.body)).data;

      if (result.isDirectPayment) {
        directPayment(context, apiLang, result.invoiceId, result.paymentURL, mfCardInfo, func);
      }
      else
        func(MFResult.fail(new MFError(APPCONST.CONFIG_ERROR, APPCONST.accountDoNotHaveDirectPayment)));
    });
  }

  // Direct Payment
  void directPayment(BuildContext context,
      String apiLang, int invoiceId, String paymentURL, MFCardInfo request, Function func) async{

    http.post(paymentURL,
        headers: {
          HttpHeaders.contentTypeHeader: ContentType.json.toString(),
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: jsonEncode(request.toJson())).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKDirectPaymentResponse
          .fromJson(json.decode(response.body)).data;

      print(result.toJson());

      if(request.bypass3DS) {
        var request = MFPaymentStatusRequest(paymentId: result.paymentId).toJson();
        paymentStatus(apiLang, request, func);
      }
      else {
        this.func = func;
        this.myContext = context;
        showWebView(result.paymentURL);
      }
    });
  }

  // Payment Status
  void paymentStatus(
      String apiLang, Map request, Function func) async{

    http.post(
        APPCONST.PAYMENT_STATUS, headers: {
      HttpHeaders.contentTypeHeader: ContentType.json.toString(),
      HttpHeaders.authorizationHeader: APPCONST.TOKEN,
      HttpHeaders.acceptLanguageHeader: apiLang
    }, body: jsonEncode(request)).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKPaymentStatusResponse
          .fromJson(json.decode(response.body)).data;

//      print(result.toJson());

      func(MFResult.success(result));
    });
  }

  void showWebView(String paymentURL) async{
//    runApp(new MyApp(paymentURL, this));
    Navigator.push(myContext,
      MaterialPageRoute(builder: (context) => MyApp(paymentURL, this)),
    );
  }

  @override
  void callBackPaymentStatus(MFResult result) {
    print("callBackPaymentStatus: ");
    if(func != null) {
      func(result);
      Navigator.pop(myContext);
    }
  }
}

abstract class CallBackPaymentStatus {
  void callBackPaymentStatus(MFResult result);
}

class MyApp extends StatefulWidget {

  var paymentURL = "";
  CallBackPaymentStatus callBackPaymentStatus;
  MyApp(String paymentURL, CallBackPaymentStatus callBackPaymentStatus) {
    this.paymentURL = paymentURL;
    this.callBackPaymentStatus = callBackPaymentStatus;
  }

  @override
  _MyAppState createState() => new _MyAppState(paymentURL, callBackPaymentStatus);
}

class _MyAppState extends State<MyApp> {

  var paymentURL = "";
  CallBackPaymentStatus callBackPaymentStatus;
  _MyAppState(String paymentURL, CallBackPaymentStatus callBackPaymentStatus) {
    this.paymentURL = paymentURL;
    this.callBackPaymentStatus = callBackPaymentStatus;
  }

  InAppWebViewController webView;
  String url = "";
  double progress = 0;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('InAppWebView Example'),
        ),
        body: Container(
            child: Column(children: <Widget>[
              Container(
                padding: EdgeInsets.all(20.0),
                child: Text(
                    "CURRENT URL\n${(url.length > 50) ? url.substring(0, 50) + "..." : url}"),
              ),
              Container(
                  padding: EdgeInsets.all(10.0),
                  child: progress < 1.0
                      ? LinearProgressIndicator(value: progress)
                      : Container()),
              Expanded(
                child: Container(
                  margin: const EdgeInsets.all(10.0),
                  decoration:
                  BoxDecoration(border: Border.all(color: Colors.blueAccent)),
                  child: InAppWebView(
                    initialUrl: paymentURL,
                    initialHeaders: {},
                    initialOptions: InAppWebViewWidgetOptions(
                        inAppWebViewOptions: InAppWebViewOptions(
                          debuggingEnabled: true,
                        )
                    ),
                    onWebViewCreated: (InAppWebViewController controller) {
                      webView = controller;
                    },
                    onLoadStart: (InAppWebViewController controller, String url) {
                      setState(() {
                        if(url.contains(APPCONST.CALL_BACK_URL) || url.contains(APPCONST.ERROR_URL)) {
                          var request = MFPaymentStatusRequest(paymentId:
                          Uri.parse(url).queryParameters["paymentId"]).toJson();
                          MFSDK.paymentStatus("en", request, (MFResult result) => {
                            callBackPaymentStatus.callBackPaymentStatus(result)
                          });
                        }
                        this.url = url;
                      });
                    },
                    onLoadStop: (InAppWebViewController controller, String url) async {
                      setState(() {
                        this.url = url;
                      });
                    },
                    onProgressChanged: (InAppWebViewController controller, int progress) {
                      setState(() {
                        this.progress = progress / 100;
                      });
                    },
                  ),
                ),
              ),
              ButtonBar(
                alignment: MainAxisAlignment.center,
                children: <Widget>[
                  RaisedButton(
                    child: Icon(Icons.arrow_back),
                    onPressed: () {
                      if (webView != null) {
                        webView.goBack();
                      }
                    },
                  ),
                  RaisedButton(
                    child: Icon(Icons.arrow_forward),
                    onPressed: () {
                      if (webView != null) {
                        webView.goForward();
                      }
                    },
                  ),
                  RaisedButton(
                    child: Icon(Icons.refresh),
                    onPressed: () {
                      if (webView != null) {
                        webView.reload();
                      }
                    },
                  ),
                ],
              ),
            ])),
      ),
    );
  }
}

//class Mfsdk {
//  static const MethodChannel _channel =
//      const MethodChannel('mfsdk');
//
//  static Future<String> get platformVersion async {
//    final String version = await _channel.invokeMethod('getPlatformVersion');
//    return version;
//  }
//}

==> 0.1.4.tar.gz: lib/mfsdk.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';

import 'package:mfsdk/model/MFError.dart';
import 'package:mfsdk/model/directpayment/MFCardInfo.dart';
import 'package:mfsdk/model/directpayment/SDKDirectPaymentResponse.dart';
import 'package:mfsdk/model/executepayment/MFExecutePaymentRequest.dart';
import 'package:mfsdk/model/executepayment/SDKExecutePaymentResponse.dart';
import 'package:mfsdk/model/MyBaseResponse.dart';
import 'package:mfsdk/model/initpayment/SDKInitiatePaymentResponse.dart';
import 'package:mfsdk/model/paymentstatus/MFPaymentStatusRequest.dart';
import 'package:mfsdk/model/paymentstatus/SDKPaymentStatusResponse.dart';
import 'package:mfsdk/views/MFResult.dart';
import 'package:mfsdk/views/APPCONST.dart';

import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:http/http.dart' as http;
import 'dart:convert';
import 'dart:io';

// Export all MyFatoorah SDK packages
export 'package:mfsdk/model/directpayment/MFCardInfo.dart';
export 'package:mfsdk/model/directpayment/SDKDirectPaymentResponse.dart';
export 'package:mfsdk/model/executepayment/MFExecutePaymentRequest.dart';
export 'package:mfsdk/model/executepayment/SDKExecutePaymentResponse.dart';
export 'package:mfsdk/model/initpayment/MFInitiatePaymentRequest.dart';
export 'package:mfsdk/model/initpayment/SDKInitiatePaymentResponse.dart';
export 'package:mfsdk/model/MFError.dart';
export 'package:mfsdk/model/MyBaseResponse.dart';
export 'package:mfsdk/model/paymentstatus/MFPaymentStatusRequest.dart';
export 'package:mfsdk/model/paymentstatus/SDKPaymentStatusResponse.dart';
export 'package:mfsdk/views/APPCONST.dart';
export 'package:mfsdk/views/MFResult.dart';

var MFSDK = new MyFatoorahSDK();

class MyFatoorahSDK implements CallBackPaymentStatus {

  static const MethodChannel _channel =
  const MethodChannel('mfsdk');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Function func;
  BuildContext myContext;

  // Initiate Payment
  void initiatePayment(String apiLang, Map request, Function func) async{

    http.post(
        APPCONST.INITIATE_PAYMENT,
        headers: {
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: request).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKInitiatePaymentResponse
          .fromJson(json.decode(response.body)).data;
      print(result.toJson());
      func(MFResult.success(result));
    });

//    func((await MFSDKController().initiatePaymentAPI(apiLang, url, token, data)).data);
  }

  // Execute  Payment
  void executePayment(BuildContext context,
      MFExecutePaymentRequest request, String apiLang, Function func) async{

    if(request.callBackUrl == null || request.callBackUrl.isEmpty)
      request.callBackUrl = APPCONST.CALL_BACK_URL;

    if(request.errorUrl == null || request.errorUrl.isEmpty)
      request.errorUrl = APPCONST.ERROR_URL;

    http.post(
        APPCONST.EXECUTE_PAYMENT,
        headers: {
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: request.toJson()).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        print("statusCode: " + statusCode.toString());
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKExecutePaymentResponse
          .fromJson(json.decode(response.body)).data;

      if (!result.isDirectPayment) {
        this.func = func;
        this.myContext = context;
        showWebView(result.paymentURL);
      }
      else
        func(MFResult.fail(new MFError(APPCONST.CONFIG_ERROR, APPCONST.incorrectPaymentMethod)));
    });
  }

  // Execute Direct Payment
  void executeDirectPayment(BuildContext context,
      MFExecutePaymentRequest request, MFCardInfo mfCardInfo, String apiLang,
      Function func) async{

    if(request.callBackUrl == null || request.callBackUrl.isEmpty)
      request.callBackUrl = APPCONST.CALL_BACK_URL;

    if(request.errorUrl == null || request.errorUrl.isEmpty)
      request.errorUrl = APPCONST.ERROR_URL;

    http.post(
        APPCONST.EXECUTE_PAYMENT,
        headers: {
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: request.toJson()).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        print("statusCode: " + statusCode.toString());
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKExecutePaymentResponse
          .fromJson(json.decode(response.body)).data;

      if (result.isDirectPayment) {
        directPayment(context, apiLang, result.invoiceId, result.paymentURL, mfCardInfo, func);
      }
      else
        func(MFResult.fail(new MFError(APPCONST.CONFIG_ERROR, APPCONST.accountDoNotHaveDirectPayment)));
    });
  }

  // Direct Payment
  void directPayment(BuildContext context,
      String apiLang, int invoiceId, String paymentURL, MFCardInfo request, Function func) async{

    http.post(paymentURL,
        headers: {
          HttpHeaders.contentTypeHeader: ContentType.json.toString(),
          HttpHeaders.authorizationHeader: APPCONST.TOKEN,
          HttpHeaders.acceptLanguageHeader: apiLang
        }, body: jsonEncode(request.toJson())).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKDirectPaymentResponse
          .fromJson(json.decode(response.body)).data;

      print(result.toJson());

      if(request.bypass3DS) {
        var request = MFPaymentStatusRequest(paymentId: result.paymentId).toJson();
        paymentStatus(apiLang, request, func);
      }
      else {
        this.func = func;
        this.myContext = context;
        showWebView(result.paymentURL);
      }
    });
  }

  // Payment Status
  void paymentStatus(
      String apiLang, Map request, Function func) async{

    http.post(
        APPCONST.PAYMENT_STATUS, headers: {
      HttpHeaders.contentTypeHeader: ContentType.json.toString(),
      HttpHeaders.authorizationHeader: APPCONST.TOKEN,
      HttpHeaders.acceptLanguageHeader: apiLang
    }, body: jsonEncode(request)).then((http.Response response) {

      final int statusCode = response.statusCode;

      if (statusCode < 200 || statusCode >= 400 || json == null) {
        var error = MyBaseResponse.fromJson(json.decode(response.body));
        func(MFResult.fail(new MFError(200, error.message)));
      }

      var result = SDKPaymentStatusResponse
          .fromJson(json.decode(response.body)).data;

//      print(result.toJson());

      func(MFResult.success(result));
    });
  }

  void showWebView(String paymentURL) async{
//    runApp(new MyApp(paymentURL, this));
    Navigator.push(myContext,
      MaterialPageRoute(builder: (context) => MyApp(paymentURL, this)),
    );
  }

  @override
  void callBackPaymentStatus(MFResult result) {
    print("callBackPaymentStatus: ");
    if(func != null) {
      func(result);
      Navigator.pop(myContext);
    }
  }
}

abstract class CallBackPaymentStatus {
  void callBackPaymentStatus(MFResult result);
}

class MyApp extends StatefulWidget {

  var paymentURL = "";
  CallBackPaymentStatus callBackPaymentStatus;
  MyApp(String paymentURL, CallBackPaymentStatus callBackPaymentStatus) {
    this.paymentURL = paymentURL;
    this.callBackPaymentStatus = callBackPaymentStatus;
  }

  @override
  _MyAppState createState() => new _MyAppState(paymentURL, callBackPaymentStatus);
}

class _MyAppState extends State<MyApp> {

  var paymentURL = "";
  CallBackPaymentStatus callBackPaymentStatus;
  _MyAppState(String paymentURL, CallBackPaymentStatus callBackPaymentStatus) {
    this.paymentURL = paymentURL;
    this.callBackPaymentStatus = callBackPaymentStatus;
  }

  InAppWebViewController webView;
  String url = "";
  double progress = 0;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('InAppWebView Example'),
        ),
        body: Container(
            child: Column(children: <Widget>[
              Container(
                padding: EdgeInsets.all(20.0),
                child: Text(
                    "CURRENT URL\n${(url.length > 50) ? url.substring(0, 50) + "..." : url}"),
              ),
              Container(
                  padding: EdgeInsets.all(10.0),
                  child: progress < 1.0
                      ? LinearProgressIndicator(value: progress)
                      : Container()),
              Expanded(
                child: Container(
                  margin: const EdgeInsets.all(10.0),
                  decoration:
                  BoxDecoration(border: Border.all(color: Colors.blueAccent)),
                  child: InAppWebView(
                    initialUrl: paymentURL,
                    initialHeaders: {},
                    initialOptions: InAppWebViewWidgetOptions(
                        inAppWebViewOptions: InAppWebViewOptions(
                          debuggingEnabled: true,
                        )
                    ),
                    onWebViewCreated: (InAppWebViewController controller) {
                      webView = controller;
                    },
                    onLoadStart: (InAppWebViewController controller, String url) {
                      setState(() {
                        if(url.contains(APPCONST.CALL_BACK_URL) || url.contains(APPCONST.ERROR_URL)) {
                          var request = MFPaymentStatusRequest(paymentId:
                          Uri.parse(url).queryParameters["paymentId"]).toJson();
                          MFSDK.paymentStatus("en", request, (MFResult result) => {
                            callBackPaymentStatus.callBackPaymentStatus(result)
                          });
                        }
                        this.url = url;
                      });
                    },
                    onLoadStop: (InAppWebViewController controller, String url) async {
                      setState(() {
                        this.url = url;
                      });
                    },
                    onProgressChanged: (InAppWebViewController controller, int progress) {
                      setState(() {
                        this.progress = progress / 100;
                      });
                    },
                  ),
                ),
              ),
              ButtonBar(
                alignment: MainAxisAlignment.center,
                children: <Widget>[
                  RaisedButton(
                    child: Icon(Icons.arrow_back),
                    onPressed: () {
                      if (webView != null) {
                        webView.goBack();
                      }
                    },
                  ),
                  RaisedButton(
                    child: Icon(Icons.arrow_forward),
                    onPressed: () {
                      if (webView != null) {
                        webView.goForward();
                      }
                    },
                  ),
                  RaisedButton(
                    child: Icon(Icons.refresh),
                    onPressed: () {
                      if (webView != null) {
                        webView.reload();
                      }
                    },
                  ),
                ],
              ),
            ])),
      ),
    );
  }
}

//class Mfsdk {
//  static const MethodChannel _channel =
//      const MethodChannel('mfsdk');
//
//  static Future<String> get platformVersion async {
//    final String version = await _channel.invokeMethod('getPlatformVersion');
//    return version;
//  }
//}
